import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 字典项目服务对象基类
 *
 * @export
 * @class IBZDictItemServiceBase
 * @extends {EntityServie}
 */
export default class IBZDictItemServiceBase extends EntityService {

    /**
     * Creates an instance of  IBZDictItemServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  IBZDictItemServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof IBZDictItemServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='ibzdictitem';
        this.APPDEKEY = 'itemid';
        this.APPDENAME = 'ibzdictitems';
        this.APPDETEXT = 'itemname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().get(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}/select`,isloading);
        }
            return Http.getInstance().get(`/ibzdictitems/${context.ibzdictitem}/select`,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().get(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/ibzdictitems/${context.ibzdictitem}`,isloading);
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && true){
            return Http.getInstance().get(`/ibzdicts/${context.ibzdict}/ibzdictitems/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/ibzdictitems/getdraft`,isloading);
        res.data.ibzdictitem = data.ibzdictitem;
        return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().post(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}/save`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/ibzdictitems/${context.ibzdictitem}/save`,data,isloading);
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().post(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/ibzdictitems/${context.ibzdictitem}/checkkey`,data,isloading);
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().delete(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}`,isloading);
        }
            return Http.getInstance().delete(`/ibzdictitems/${context.ibzdictitem}`,isloading);

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && true){
            data[this.APPDEKEY] = null;
            return Http.getInstance().post(`/ibzdicts/${context.ibzdict}/ibzdictitems`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/ibzdictitems`,data,isloading);
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && context.ibzdictitem){
            return Http.getInstance().put(`/ibzdicts/${context.ibzdict}/ibzdictitems/${context.ibzdictitem}`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/ibzdictitems/${context.ibzdictitem}`,data,isloading);
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictItemServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.ibzdict && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/ibzdicts/${context.ibzdict}/ibzdictitems/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/ibzdictitems/fetchdefault`,tempData,isloading);
    }
}